Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(223)

Unified Diff: ash/shell_delegate.h

Issue 2046843005: mash: Migrate shelf menus to wm common types (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: ash_shell_with_content Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/shell/shell_delegate_impl.cc ('k') | ash/sysui/context_menu_mus.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/shell_delegate.h
diff --git a/ash/shell_delegate.h b/ash/shell_delegate.h
index 468fa62736ab53f0f83da5cfdbaad81d107b199d..978b21a65eac84f2d3b9016c8962b1f260abfd88 100644
--- a/ash/shell_delegate.h
+++ b/ash/shell_delegate.h
@@ -52,8 +52,8 @@ class ShelfDelegate;
class ShelfModel;
class SystemTrayDelegate;
class UserWallpaperDelegate;
-class Shelf;
struct ShelfItem;
+class WmShelf;
class ASH_EXPORT VirtualKeyboardStateObserver {
public:
@@ -150,10 +150,10 @@ class ASH_EXPORT ShellDelegate {
virtual std::unique_ptr<ContainerDelegate> CreateContainerDelegate() = 0;
// Creates a menu model for the |shelf| and optional shelf |item|.
// If |item| is null, this creates a context menu for the desktop or shelf.
- virtual ui::MenuModel* CreateContextMenu(ash::Shelf* shelf,
- const ash::ShelfItem* item) = 0;
+ virtual ui::MenuModel* CreateContextMenu(WmShelf* wm_shelf,
+ const ShelfItem* item) = 0;
// Creates a GPU support object. Shell takes ownership of the object.
virtual GPUSupport* CreateGPUSupport() = 0;
« no previous file with comments | « ash/shell/shell_delegate_impl.cc ('k') | ash/sysui/context_menu_mus.h » ('j') | no next file with comments »
@@ -150,10 +150,10 @@ class ASH_EXPORT ShellDelegate {
virtual std::unique_ptr<ContainerDelegate> CreateContainerDelegate() = 0;
- // Creates a menu model for the |shelf| and optional shelf |item|.
+ // Creates a menu model for the |wm_shelf| and optional shelf |item|.
// If |item| is null, this creates a context menu for the desktop or shelf.

Powered by Google App Engine
This is Rietveld 408576698